@@ -36,8 +36,7 @@
 class KActionCollection;
 class QAction;
 
-namespace MessageComposer
-{
+namespace MessageComposer {
 class AttachmentModel;
 class MESSAGECOMPOSER_EXPORT AttachmentControllerBase : public QObject
 {
@@ -62,18 +61,18 @@ public Q_SLOTS:
     void setEncryptEnabled(bool enabled);
     void setSignEnabled(bool enabled);
     /// compression is async...
-    void compressAttachment(MessageCore::AttachmentPart::Ptr part, bool compress);
+    void compressAttachment(const MessageCore::AttachmentPart::Ptr &part, bool compress);
     void showContextMenu();
-    void openAttachment(MessageCore::AttachmentPart::Ptr part);
-    void viewAttachment(MessageCore::AttachmentPart::Ptr part);
+    void openAttachment(const MessageCore::AttachmentPart::Ptr &part);
+    void viewAttachment(const MessageCore::AttachmentPart::Ptr &part);
     void editAttachment(MessageCore::AttachmentPart::Ptr part, MessageViewer::EditorWatcher::OpenWithOption option = MessageViewer::EditorWatcher::NoOpenWithDialog);
-    void editAttachmentWith(MessageCore::AttachmentPart::Ptr part);
-    void saveAttachmentAs(MessageCore::AttachmentPart::Ptr part);
-    void attachmentProperties(MessageCore::AttachmentPart::Ptr part);
+    void editAttachmentWith(const MessageCore::AttachmentPart::Ptr &part);
+    void saveAttachmentAs(const MessageCore::AttachmentPart::Ptr &part);
+    void attachmentProperties(const MessageCore::AttachmentPart::Ptr &part);
     void showAddAttachmentFileDialog();
     void showAddAttachmentCompressedDirectoryDialog();
     /// sets sign, encrypt, shows properties dialog if so configured
-    void addAttachment(MessageCore::AttachmentPart::Ptr part);
+    void addAttachment(const MessageCore::AttachmentPart::Ptr &part);
     void addAttachment(const QUrl &url);
     void addAttachmentUrlSync(const QUrl &url);
     void addAttachments(const QList<QUrl> &urls);
@@ -99,8 +98,6 @@ protected:
 private:
     void attachFiles(const QList<QUrl> &urls, const QString &encoding);
     void attachDirectory(const QUrl &url);
-
-private Q_SLOTS:
     void slotPutResult(KJob *job);
     void slotOpenWithDialog();
     void slotOpenWithAction(QAction *act);
@@ -108,25 +105,7 @@ private Q_SLOTS:
 private:
     class Private;
     Private *const d;
-
-    Q_PRIVATE_SLOT(d, void attachmentRemoved(MessageCore::AttachmentPart::Ptr))
-    Q_PRIVATE_SLOT(d, void compressJobResult(KJob *))
-    Q_PRIVATE_SLOT(d, void loadJobResult(KJob *))
-    Q_PRIVATE_SLOT(d, void openSelectedAttachments())
-    Q_PRIVATE_SLOT(d, void viewSelectedAttachments())
-    Q_PRIVATE_SLOT(d, void editSelectedAttachment())
-    Q_PRIVATE_SLOT(d, void editSelectedAttachmentWith())
-    Q_PRIVATE_SLOT(d, void removeSelectedAttachments())
-    Q_PRIVATE_SLOT(d, void saveSelectedAttachmentAs())
-    Q_PRIVATE_SLOT(d, void selectedAttachmentProperties())
-    Q_PRIVATE_SLOT(d, void editDone(MessageViewer::EditorWatcher *))
-    Q_PRIVATE_SLOT(d, void attachPublicKeyJobResult(KJob *))
-    Q_PRIVATE_SLOT(d, void slotAttachmentContentCreated(KJob *))
-    Q_PRIVATE_SLOT(d, void reloadAttachment())
-    Q_PRIVATE_SLOT(d, void updateJobResult(KJob *))
-    Q_PRIVATE_SLOT(d, void attachVcardFromAddressBook(KJob *))
 };
-
 } //
 
 #endif // KMAIL_ATTACHMENTCONTROLLERBASE_H
