@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,8 +23,6 @@
 #include "richtextcomposersignatures.h"
 #include <pimcommon/autocorrection.h>
 
-#include <QTextBlock>
-
 #include <part/textpart.h>
 #include "settings/messagecomposersettings.h"
 #include <grantlee/markupdirector.h>
@@ -36,24 +34,23 @@ class MessageComposer::RichTextComposerNgPrivate
 {
 public:
     RichTextComposerNgPrivate(RichTextComposerNg *q)
-        : autoCorrection(nullptr),
-          richtextComposer(q)
+        : autoCorrection(nullptr)
+        , richtextComposer(q)
     {
         richTextComposerSignatures = new MessageComposer::RichTextComposerSignatures(richtextComposer, richtextComposer);
     }
 
     void fixHtmlFontSize(QString &cleanHtml);
     QString toCleanHtml() const;
-    PimCommon::AutoCorrection *autoCorrection;
-    RichTextComposerNg *richtextComposer;
-    MessageComposer::RichTextComposerSignatures *richTextComposerSignatures;
+    PimCommon::AutoCorrection *autoCorrection = nullptr;
+    RichTextComposerNg *richtextComposer = nullptr;
+    MessageComposer::RichTextComposerSignatures *richTextComposerSignatures = nullptr;
 };
 
 RichTextComposerNg::RichTextComposerNg(QWidget *parent)
-    : KPIMTextEdit::RichTextComposer(parent),
-      d(new MessageComposer::RichTextComposerNgPrivate(this))
+    : KPIMTextEdit::RichTextComposer(parent)
+    , d(new MessageComposer::RichTextComposerNgPrivate(this))
 {
-
 }
 
 RichTextComposerNg::~RichTextComposerNg()
@@ -85,8 +82,8 @@ void RichTextComposerNg::setAutocorrectionLanguage(const QString &lang)
 
 static bool isSpecial(const QTextCharFormat &charFormat)
 {
-    return charFormat.isFrameFormat() || charFormat.isImageFormat() ||
-           charFormat.isListFormat() || charFormat.isTableFormat() || charFormat.isTableCellFormat();
+    return charFormat.isFrameFormat() || charFormat.isImageFormat()
+           || charFormat.isListFormat() || charFormat.isTableFormat() || charFormat.isTableCellFormat();
 }
 
 bool RichTextComposerNg::processAutoCorrection(QKeyEvent *e)
@@ -115,7 +112,6 @@ bool RichTextComposerNg::processAutoCorrection(QKeyEvent *e)
                         setTextCursor(cur);
                     }
                 } else {
-
                     const QChar insertChar = spacePressed ? QLatin1Char(' ') : QLatin1Char('\n');
                     if (richText && !isSpecial(initialTextFormat)) {
                         if ((spacePressed && addSpace) || !spacePressed) {
@@ -148,7 +144,7 @@ void RichTextComposerNgPrivate::fixHtmlFontSize(QString &cleanHtml)
         const QString fontSizeStr = styleRegex.cap(1);
         const int ptValue = fontSizeStr.toInt(&ok);
         if (ok) {
-            double emValue = (double)ptValue / 12;
+            double emValue = static_cast<double>(ptValue) / 12;
             const QString emValueStr = QString::number(emValue, 'g', 2);
             cleanHtml.replace(styleRegex.pos(1), QString(fontSizeStr + QLatin1String("px")).length(), emValueStr + QLatin1String("em"));
         }
@@ -159,22 +155,34 @@ void RichTextComposerNgPrivate::fixHtmlFontSize(QString &cleanHtml)
     }
 }
 
+bool RichTextComposerNg::convertPlainText(MessageComposer::TextPart *textPart)
+{
+    return false;
+}
+
 void RichTextComposerNg::fillComposerTextPart(MessageComposer::TextPart *textPart)
 {
-    if (composerControler()->isFormattingUsed() && MessageComposer::MessageComposerSettings::self()->improvePlainTextOfHtmlMessage()) {
-        Grantlee::PlainTextMarkupBuilder *pb = new Grantlee::PlainTextMarkupBuilder();
+    if (composerControler()->isFormattingUsed()) {
+        if (!convertPlainText(textPart)) {
+            if (MessageComposer::MessageComposerSettings::self()->improvePlainTextOfHtmlMessage()) {
+                Grantlee::PlainTextMarkupBuilder *pb = new Grantlee::PlainTextMarkupBuilder();
 
-        Grantlee::MarkupDirector *pmd = new Grantlee::MarkupDirector(pb);
-        pmd->processDocument(document());
-        const QString plainText = pb->getResult();
-        textPart->setCleanPlainText(composerControler()->toCleanPlainText(plainText));
-        QTextDocument *doc = new QTextDocument(plainText);
-        doc->adjustSize();
+                Grantlee::MarkupDirector *pmd = new Grantlee::MarkupDirector(pb);
+                pmd->processDocument(document());
+                const QString plainText = pb->getResult();
+                textPart->setCleanPlainText(composerControler()->toCleanPlainText(plainText));
+                QTextDocument *doc = new QTextDocument(plainText);
+                doc->adjustSize();
 
-        textPart->setWrappedPlainText(composerControler()->toWrappedPlainText(doc));
-        delete doc;
-        delete pmd;
-        delete pb;
+                textPart->setWrappedPlainText(composerControler()->toWrappedPlainText(doc));
+                delete doc;
+                delete pmd;
+                delete pb;
+            } else {
+                textPart->setCleanPlainText(composerControler()->toCleanPlainText());
+                textPart->setWrappedPlainText(composerControler()->toWrappedPlainText());
+            }
+        }
     } else {
         textPart->setCleanPlainText(composerControler()->toCleanPlainText());
         textPart->setWrappedPlainText(composerControler()->toWrappedPlainText());
@@ -186,7 +194,6 @@ void RichTextComposerNg::fillComposerTextPart(MessageComposer::TextPart *textPar
         textPart->setCleanHtml(cleanHtml);
         textPart->setEmbeddedImages(composerControler()->composerImages()->embeddedImages());
     }
-
 }
 
 QString RichTextComposerNgPrivate::toCleanHtml() const
@@ -194,25 +201,25 @@ QString RichTextComposerNgPrivate::toCleanHtml() const
     QString result = richtextComposer->toHtml();
 
     static const QString EMPTYLINEHTML = QStringLiteral(
-            "<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; "
-            "margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; \">&nbsp;</p>");
+        "<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; "
+        "margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; \">&nbsp;</p>");
 
     // Qt inserts various style properties based on the current mode of the editor (underline,
     // bold, etc), but only empty paragraphs *also* have qt-paragraph-type set to 'empty'.
     static const QString EMPTYLINEREGEX = QStringLiteral(
-            "<p style=\"-qt-paragraph-type:empty;(.*)</p>");
+        "<p style=\"-qt-paragraph-type:empty;(.*)</p>");
 
     static const QString OLLISTPATTERNQT = QStringLiteral(
-            "<ol style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
+        "<ol style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
 
     static const QString ULLISTPATTERNQT = QStringLiteral(
-            "<ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
+        "<ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px;");
 
     static const QString ORDEREDLISTHTML = QStringLiteral(
-            "<ol style=\"margin-top: 0px; margin-bottom: 0px;");
+        "<ol style=\"margin-top: 0px; margin-bottom: 0px;");
 
     static const QString UNORDEREDLISTHTML = QStringLiteral(
-                "<ul style=\"margin-top: 0px; margin-bottom: 0px;");
+        "<ul style=\"margin-top: 0px; margin-bottom: 0px;");
 
     // fix 1 - empty lines should show as empty lines - MS Outlook treats margin-top:0px; as
     // a non-existing line.
@@ -251,14 +258,9 @@ static bool isCursorAtEndOfLine(const QTextCursor &cursor)
     return !testCursor.hasSelection();
 }
 
-static void insertSignatureHelper(const QString &signature,
-                                  RichTextComposerNg *textEdit,
-                                  KIdentityManagement::Signature::Placement placement,
-                                  bool isHtml,
-                                  bool addNewlines)
+static void insertSignatureHelper(const QString &signature, RichTextComposerNg *textEdit, KIdentityManagement::Signature::Placement placement, bool isHtml, bool addNewlines)
 {
     if (!signature.isEmpty()) {
-
         // Save the modified state of the document, as inserting a signature
         // shouldn't change this. Restore it at the end of this function.
         bool isModified = textEdit->document()->isModified();
@@ -350,8 +352,8 @@ void RichTextComposerNg::insertSignature(const KIdentityManagement::Signature &s
         }
 
         insertSignatureHelper(signatureStr, this, placement,
-                              (signature.isInlinedHtml() &&
-                               signature.type() == KIdentityManagement::Signature::Inlined),
+                              (signature.isInlinedHtml()
+                               && signature.type() == KIdentityManagement::Signature::Inlined),
                               (addedText & KIdentityManagement::Signature::AddNewLines));
 
         // We added the text of the signature above, now it is time to add the images as well.
