@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -31,22 +31,21 @@ public:
     FollowupReminderCreateJobPrivate()
         : mInfo(new FollowUpReminder::FollowUpReminderInfo)
     {
-
     }
+
     ~FollowupReminderCreateJobPrivate()
     {
         delete mInfo;
     }
 
     Akonadi::Collection mCollection;
-    FollowUpReminder::FollowUpReminderInfo *mInfo;
+    FollowUpReminder::FollowUpReminderInfo *mInfo = nullptr;
 };
 
 FollowupReminderCreateJob::FollowupReminderCreateJob(QObject *parent)
-    : KJob(parent),
-      d(new MessageComposer::FollowupReminderCreateJobPrivate)
+    : KJob(parent)
+    , d(new MessageComposer::FollowupReminderCreateJobPrivate)
 {
-
 }
 
 FollowupReminderCreateJob::~FollowupReminderCreateJob()
@@ -89,7 +88,7 @@ void FollowupReminderCreateJob::start()
     if (d->mInfo->isValid()) {
         if (d->mCollection.isValid()) {
             KCalCore::Todo::Ptr todo(new KCalCore::Todo);
-            todo->setSummary(i18n("Wait answer from \"%1\" send to \"%2\"").arg(d->mInfo->subject(), d->mInfo->to()));
+            todo->setSummary(i18n("Wait answer from \"%1\" send to \"%2\"", d->mInfo->subject(), d->mInfo->to()));
             Akonadi::Item newTodoItem;
             newTodoItem.setMimeType(KCalCore::Todo::todoMimeType());
             newTodoItem.setPayload<KCalCore::Todo::Ptr>(todo);
@@ -101,7 +100,7 @@ void FollowupReminderCreateJob::start()
         }
     } else {
         qCDebug(MESSAGECOMPOSER_LOG) << "FollowupReminderCreateJob info not valid ";
-        Q_EMIT emitResult();
+        emitResult();
         return;
     }
 }
@@ -120,5 +119,5 @@ void FollowupReminderCreateJob::slotCreateNewTodo(KJob *job)
 void FollowupReminderCreateJob::writeFollowupReminderInfo()
 {
     FollowUpReminder::FollowUpReminderUtil::writeFollowupReminderInfo(FollowUpReminder::FollowUpReminderUtil::defaultConfig(), d->mInfo, true);
-    Q_EMIT emitResult();
+    emitResult();
 }
