@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,17 +25,15 @@
 using namespace MessageComposer;
 
 MessageFactoryForwardJob::MessageFactoryForwardJob(QObject *parent)
-    : QObject(parent),
-      mMsg(nullptr),
-      mOrigMsg(nullptr),
-      mIdentityManager(nullptr)
+    : QObject(parent)
+    , mMsg(nullptr)
+    , mOrigMsg(nullptr)
+    , mIdentityManager(nullptr)
 {
-
 }
 
 MessageFactoryForwardJob::~MessageFactoryForwardJob()
 {
-
 }
 
 void MessageFactoryForwardJob::start()
