@@ -23,9 +23,7 @@
 #include "contentjobbase.h"
 #include "messagecomposer_export.h"
 
-namespace MessageComposer
-{
-
+namespace MessageComposer {
 class MultipartJobPrivate;
 
 /**
@@ -36,7 +34,7 @@ class MESSAGECOMPOSER_EXPORT MultipartJob : public ContentJobBase
 
 public:
     explicit MultipartJob(QObject *parent = nullptr);
-    virtual ~MultipartJob();
+    ~MultipartJob() override;
 
     QByteArray multipartSubtype() const;
     void setMultipartSubtype(const QByteArray &subtype);
@@ -47,7 +45,6 @@ protected Q_SLOTS:
 private:
     Q_DECLARE_PRIVATE(MultipartJob)
 };
-
 }
 
 #endif
