@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,28 +21,6 @@
 
 using namespace MessageComposer;
 
-ActionType::ActionType()
-    : mAction(nullptr)
-    , mType(Tools)
-{
-}
-
-ActionType::ActionType(QAction *action, ActionType::Type type)
-    : mAction(action)
-    , mType(type)
-{
-}
-
-QAction *ActionType::action() const
-{
-    return mAction;
-}
-
-ActionType::Type ActionType::type() const
-{
-    return mType;
-}
-
 class MessageComposer::PluginEditorInterfacePrivate
 {
 public:
@@ -50,10 +28,11 @@ public:
     {
     }
 
-    ActionType mActionType;
+    PluginActionType mActionType;
     QWidget *mParentWidget = nullptr;
     KPIMTextEdit::RichTextEditor *mRichTextEditor = nullptr;
     PluginEditor *plugin = nullptr;
+    bool mSelectedText = false;
 };
 
 PluginEditorInterface::PluginEditorInterface(QObject *parent)
@@ -67,12 +46,12 @@ PluginEditorInterface::~PluginEditorInterface()
     delete d;
 }
 
-void PluginEditorInterface::setActionType(ActionType type)
+void PluginEditorInterface::setActionType(PluginActionType type)
 {
     d->mActionType = type;
 }
 
-ActionType PluginEditorInterface::actionType() const
+PluginActionType PluginEditorInterface::actionType() const
 {
     return d->mActionType;
 }
@@ -87,25 +66,12 @@ void PluginEditorInterface::setRichTextEditor(KPIMTextEdit::RichTextEditor *rich
     d->mRichTextEditor = richTextEditor;
 }
 
-QString PluginEditorInterface::actionXmlExtension(ActionType::Type type)
+void PluginEditorInterface::setNeedSelectedText(bool b)
 {
-    switch (type) {
-    case MessageComposer::ActionType::Tools:
-        return QStringLiteral("_plugins_tools");
-    case MessageComposer::ActionType::Edit:
-        return QStringLiteral("_plugins_edit");
-    case MessageComposer::ActionType::File:
-        return QStringLiteral("_plugins_file");
-    case MessageComposer::ActionType::Action:
-        return QStringLiteral("_plugins_actions");
-    case MessageComposer::ActionType::PopupMenu:
-        return QStringLiteral("_popupmenu_actions");
-    case MessageComposer::ActionType::ToolBar:
-        return QStringLiteral("_toolbar_actions");
-    case MessageComposer::ActionType::Options:
-        return QStringLiteral("_plugins_options");
-    case MessageComposer::ActionType::None:
-        return QString();
-    }
-    return {};
+    d->mSelectedText = b;
+}
+
+bool PluginEditorInterface::needSelectedText() const
+{
+    return d->mSelectedText;
 }
