@@ -18,30 +18,25 @@
  *
  *******************************************************************************/
 
-#ifndef __MESSAGELIST_CORE_MESSAGEITEM_H__
-#define __MESSAGELIST_CORE_MESSAGEITEM_H__
+#ifndef MESSAGELIST_CORE_MESSAGEITEM_H
+#define MESSAGELIST_CORE_MESSAGEITEM_H
 
-#include <core/item.h>
-#include <core/modelinvariantindex.h>
+#include "core/item.h"
+#include "core/modelinvariantindex.h"
 
 #include <QPixmap>
 #include <QString>
 #include <QColor>
-
+#include <QFont>
 #include <messagelist_export.h>
 #include "theme.h"
 
-namespace Akonadi
-{
+namespace Akonadi {
 class Item;
 }
 
-namespace MessageList
-{
-
-namespace Core
-{
-
+namespace MessageList {
+namespace Core {
 class MessageItemPrivate;
 
 class MESSAGELIST_EXPORT MessageItem : public Item, public ModelInvariantIndex
@@ -234,9 +229,7 @@ public:
 private:
     Q_DECLARE_PRIVATE(FakeItem)
 };
-
 } // namespace Core
-
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_CORE_MESSAGEITEM_H__
+#endif //!__MESSAGELIST_CORE_MESSAGEITEM_H
