@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,10 +20,8 @@
 
 #include <KMessageWidget>
 #include "messagelist_private_export.h"
-namespace MessageList
-{
-namespace Core
-{
+namespace MessageList {
+namespace Core {
 class MESSAGELIST_TESTS_EXPORT QuickSearchWarning : public KMessageWidget
 {
     Q_OBJECT
