@@ -1,6 +1,6 @@
 /*
   This file is part of KMail, the KDE mail client.
-  Copyright (c) 2011-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2011-2018 Montel Laurent <montel@kde.org>
 
   KMail is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -79,7 +79,7 @@ QString MessageList::Util::storageModelSelectedMessageGroup()
 
 void MessageList::Util::deleteConfig(const QString &collectionId)
 {
-    KConfigGroup confselectedMessage(MessageList::MessageListSettings::self()->config(),
+    KConfigGroup confselectedMessage(MessageListSettings::self()->config(),
                                      MessageList::Util::storageModelSelectedMessageGroup());
     confselectedMessage.deleteEntry(MessageList::Util::messageUniqueIdConfigName().arg(collectionId));
 
@@ -97,7 +97,6 @@ void MessageList::Util::deleteConfig(const QString &collectionId)
     KConfigGroup storageModelAggregation(MessageListSettings::self()->config(),
                                          MessageList::Util::storageModelAggregationsGroup());
     storageModelAggregation.deleteEntry(collectionId + setForStorageModelConfigName());
-
 }
 
 QColor MessageList::Util::unreadDefaultMessageColor()
@@ -168,4 +167,3 @@ QString MessageList::Util::contentSummary(const Akonadi::Item &item)
     }
     return ret.toHtmlEscaped();
 }
-
