@@ -16,8 +16,8 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
-#ifndef __MESSAGELIST_STORAGEMODEL_H__
-#define __MESSAGELIST_STORAGEMODEL_H__
+#ifndef MESSAGELIST_STORAGEMODEL_H
+#define MESSAGELIST_STORAGEMODEL_H
 
 #include <messagelist_export.h>
 #include <messagelist/storagemodelbase.h>
@@ -51,7 +51,7 @@ public:
     * Create a StorageModel wrapping the specified folder.
     */
     explicit StorageModel(QAbstractItemModel *model, QItemSelectionModel *selectionModel, QObject *parent = nullptr);
-    ~StorageModel();
+    ~StorageModel() override;
 
     Akonadi::Collection::List displayedCollections() const;
 
@@ -91,4 +91,4 @@ private:
 };
 } // namespace MessageList
 
-#endif //!__MESSAGELIST_STORAGEMODEL_H__
+#endif //!__MESSAGELIST_STORAGEMODEL_H
