@@ -29,7 +29,7 @@
 #include <QGridLayout>
 #include <QPushButton>
 #include <QFrame>
-#include <QHash>
+#include <QMap>
 
 #include <KLocalizedString>
 #include <KIconLoader>
@@ -169,8 +169,7 @@ ConfigureAggregationsDialog::ConfigureAggregationsDialog(QWidget *parent)
     d->mEditor = new AggregationEditor(base);
     g->addWidget(d->mEditor, 8, 0, 1, 2);
 
-    connect(d->mEditor, SIGNAL(aggregationNameChanged()),
-            SLOT(editedAggregationNameChanged()));
+    connect(d->mEditor, &AggregationEditor::aggregationNameChanged, this, [this]() { d->editedAggregationNameChanged(); });
 
     g->setColumnStretch(0, 1);
     g->setRowStretch(7, 1);
@@ -258,9 +257,9 @@ void ConfigureAggregationsDialog::Private::fillAggregationList()
     if (!Manager::instance()) {
         return;
     }
-    const QHash< QString, Aggregation * > &sets = Manager::instance()->aggregations();
-    QHash< QString, Aggregation * >::ConstIterator end(sets.constEnd());
-    for (QHash< QString, Aggregation * >::ConstIterator it = sets.constBegin(); it != end; ++it) {
+    const QMap< QString, Aggregation * > &sets = Manager::instance()->aggregations();
+    QMap< QString, Aggregation * >::ConstIterator end(sets.constEnd());
+    for (QMap< QString, Aggregation * >::ConstIterator it = sets.constBegin(); it != end; ++it) {
         (void)new AggregationListWidgetItem(mAggregationList, *(*it));
     }
 }
