@@ -59,6 +59,7 @@ public:
     const HeaderStrategy *mStrategy = nullptr;
     QString mVCardName;
     QString mCollectionName;
+    QString mAttachmentHtml;
     MimeTreeParser::NodeHelper *mNodeHelper = nullptr;
     QObject *mSourceObject = nullptr;
     Akonadi::MessageStatus mMessageStatus;
@@ -79,9 +80,14 @@ HeaderStyle::~HeaderStyle()
     delete d;
 }
 
-bool HeaderStyle::hasAttachmentQuickList() const
+void HeaderStyle::setAttachmentHtml(const QString &html)
 {
-    return false;
+    d->mAttachmentHtml = html;
+}
+
+QString HeaderStyle::attachmentHtml() const
+{
+    return d->mAttachmentHtml;
 }
 
 void HeaderStyle::setMessagePath(const QString &path)
