@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -18,8 +18,8 @@
 
 */
 
-#ifndef __MIMETREEPARSER_CONVERTHTMLTOPLAINTEXT_H__
-#define __MIMETREEPARSER_CONVERTHTMLTOPLAINTEXT_H__
+#ifndef MIMETREEPARSER_CONVERTHTMLTOPLAINTEXT_H
+#define MIMETREEPARSER_CONVERTHTMLTOPLAINTEXT_H
 
 #include <QString>
 namespace MimeTreeParser {
@@ -40,4 +40,4 @@ private:
 };
 }
 
-#endif // __MIMETREEPARSER_CONVERTHTMLTOPLAINTEXT_H__
+#endif // MIMETREEPARSER_CONVERTHTMLTOPLAINTEXT_H
