@@ -17,8 +17,8 @@
    02110-1301, USA.
 */
 
-#ifndef __MESSAGEVIEWER_DEFAULTRENDERER_ATTACHMENTMESSAGEPARTRENDERER_H__
-#define __MESSAGEVIEWER_DEFAULTRENDERER_ATTACHMENTMESSAGEPARTRENDERER_H__
+#ifndef MESSAGEVIEWER_DEFAULTRENDERER_ATTACHMENTMESSAGEPARTRENDERER_H
+#define MESSAGEVIEWER_DEFAULTRENDERER_ATTACHMENTMESSAGEPARTRENDERER_H
 
 #include "../messagepartrendererbase.h"
 
@@ -27,8 +27,8 @@ class AttachmentMessagePartRenderer : public MessagePartRendererBase
 {
 public:
     AttachmentMessagePartRenderer();
-    virtual ~AttachmentMessagePartRenderer();
-    bool render(const MimeTreeParser::MessagePartPtr &msgPart, MimeTreeParser::HtmlWriter *htmlWriter, RenderContext *context) const override;
+    ~AttachmentMessagePartRenderer() override;
+    bool render(const MimeTreeParser::MessagePartPtr &msgPart, HtmlWriter *htmlWriter, RenderContext *context) const override;
 };
 }
 
