@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -29,7 +29,7 @@ class ScamAttribute : public Akonadi::Attribute
 {
 public:
     explicit ScamAttribute();
-    ~ScamAttribute();
+    ~ScamAttribute() override;
 
     ScamAttribute *clone() const override;
     QByteArray type() const override;
