@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,21 +21,17 @@
 #include "scamdetection/scamdetectionwarningwidget.h"
 #include "scamdetection/scamdetectionwebengine.h"
 
-#include <KLocalizedString>
-
 #include <QUrl>
 #include <QStandardPaths>
 #include <QVBoxLayout>
 #include <QPushButton>
 #include <QFileDialog>
 #include <QApplication>
-#include <KAboutData>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QWebEngineView>
 
-ScamDetectionWebEngineTestWidget::ScamDetectionWebEngineTestWidget(const QString &filename,
-                                                                   QWidget *parent)
+ScamDetectionWebEngineTestWidget::ScamDetectionWebEngineTestWidget(const QString &filename, QWidget *parent)
     : QWidget(parent)
 {
     mScamDetection = new MessageViewer::ScamDetectionWebEngine(this);
@@ -58,7 +54,7 @@ ScamDetectionWebEngineTestWidget::ScamDetectionWebEngineTestWidget(const QString
     mWebEngineView->load(QUrl::fromLocalFile(filename));
 
     QHBoxLayout *hbox = new QHBoxLayout;
-    QPushButton *openFile = new QPushButton(i18n("Open html..."));
+    QPushButton *openFile = new QPushButton(QStringLiteral("Open html..."));
     connect(openFile, &QPushButton::clicked, this, &ScamDetectionWebEngineTestWidget::slotOpenHtml);
     hbox->addWidget(openFile);
     lay->addLayout(hbox);
@@ -88,19 +84,12 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
 
-    KAboutData aboutData(QStringLiteral("scamdetection_gui"), i18n(
-                             "ScamDetectionTest_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for scamdetection widget"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"),
-        i18n("URL of an html file to be opened")));
-
-    aboutData.setupCommandLine(&parser);
+                                        QStringLiteral("URL of an html file to be opened")));
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     QString fileName;
     if (parser.positionalArguments().count()) {
@@ -108,7 +97,7 @@ int main(int argc, char **argv)
     } else {
         fileName
             = QFileDialog::getOpenFileName(nullptr, QString(), QString(),
-                                           i18n("HTML File (*.html)"));
+                                           QStringLiteral("HTML File (*.html)"));
     }
     if (fileName.isEmpty()) {
         return 0;
