@@ -36,6 +36,7 @@
 
 #include <QColor>
 #include <QFont>
+#include <QUrl>
 
 class QString;
 class QPaintDevice;
@@ -119,6 +120,9 @@ protected:
     // color of frame of warning preceding the source of HTML messages
     QColor cHtmlWarning;
 
+    QString imgShowUrl;
+    QString imgHideUrl;
+
 private:
     QString quoteCssDefinition() const;
     int fontSize(bool fixed, bool print = false) const;
@@ -128,6 +132,7 @@ private:
     QString screenCssDefinitions(const CSSHelperBase *helper, bool fixed) const;
     // returns CSS rules common to both screen and print media types
     QString commonCssDefinitions() const;
+    QString fullAddressList() const;
 
 private:
     const QPaintDevice *mPaintDevice = nullptr;
