@@ -1,4 +1,4 @@
-/* Copyright (C) 2011-2017 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2011-2018 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -23,8 +23,7 @@
 
 #include "kpimtextedit/plaintexteditorwidget.h"
 
-namespace TemplateParser
-{
+namespace TemplateParser {
 class TEMPLATEPARSER_EXPORT TemplatesTextEdit : public KPIMTextEdit::PlainTextEditorWidget
 {
     Q_OBJECT
@@ -32,8 +31,6 @@ public:
     explicit TemplatesTextEdit(QWidget *parent = nullptr);
     ~TemplatesTextEdit();
 };
-
 }
 
 #endif
-
