@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2016-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,22 +23,22 @@
 #include <QWidget>
 #include "../searchfullhashjob.h"
 class QLineEdit;
-class QTextEdit;
+class QPlainTextEdit;
 class SearchFullHashGui : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SearchFullHashGui(QWidget *parent = Q_NULLPTR);
+    explicit SearchFullHashGui(QWidget *parent = nullptr);
     ~SearchFullHashGui();
 private Q_SLOTS:
     void slotCheckUrl();
-    void slotGetResult(WebEngineViewer::SearchFullHashJob::UrlStatus result);
+    void slotGetResult(WebEngineViewer::CheckPhishingUrlUtil::UrlStatus result);
     void slotJSonDebug(const QByteArray &debug);
 private:
     QLineEdit *mCheckHashLineEdit;
     QLineEdit *mDataBaseHashLineEdit;
-    QTextEdit *mJson;
-    QTextEdit *mResult;
+    QPlainTextEdit *mJson;
+    QPlainTextEdit *mResult;
 };
 
 #endif // CHECKPHISHINGURLGUI_H
