@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,11 +20,9 @@
 #ifndef TestSelectionChangedEngine_H
 #define TestSelectionChangedEngine_H
 
-#include <QWebEngineView>
 #include <QWidget>
 
-namespace WebEngineViewer
-{
+namespace WebEngineViewer {
 class WebEngineView;
 }
 
